@@ -28,7 +28,7 @@ def get_videos(url, extra_params):
     ydl_params = {
         'format': 'best',
         'cachedir': False,
-        'logger': current_app.logger.getChild('youtube-dl'),
+        'logger': current_app.logger.getChild('yt-dlp'),
     }
     ydl_params.update(extra_params)
     ydl = SimpleYDL(ydl_params)
@@ -177,7 +177,7 @@ def list_extractors():
 def version():
     result = {
         'yt-dlp': '2022.3.8.2',
-        'youtube-dl-api-server': __version__,
+        'youtubedlapi-server-infusiblecoder': __version__,
     }
     return jsonify(result)
 
